"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const color_1 = require("../util/color");
const createPaletteItem = (paletteItem, theme) => {
    var _a;
    let result = {};
    if (typeof paletteItem === 'string') {
        result.main = paletteItem;
    }
    else {
        result = Object.assign({}, paletteItem);
        if (!result.main) {
            console.error('Palette main color is missing...');
        }
    }
    const mainColor = (0, color_1.getColor)(result.main);
    result.background || (result.background = result.main);
    result.font || (result.font = (0, color_1.getFontColor)(result.main, theme));
    result.shadow || (result.shadow = mainColor.alpha(.5).rgb().toString());
    result.dark || (result.dark = mainColor.darken(.075).hex().toString());
    result.darker || (result.darker = mainColor.darken(.175).hex().toString());
    result.darkest || (result.darkest = (0, color_1.getColor)(result.darker).darken(.075).hex().toString());
    result.light || (result.light = mainColor.lighten(.075).hex().toString());
    result.lighter || (result.lighter = mainColor.lighten(.175).hex().toString());
    result.lightest || (result.lightest = (0, color_1.getColor)(result.lighter).lighten(.075).hex().toString());
    result.dynamic = theme.$.vars.isDarkMode ? result.light : result.dark;
    result.dynamicer = theme.$.vars.isDarkMode ? result.lighter : result.darker;
    result.dynamicest = theme.$.vars.isDarkMode ? result.lightest : result.darkest;
    result.soft || (result.soft = (0, color_1.mix)(result.main, -.8));
    result.softFont || (result.softFont = (0, color_1.mix)(result.main, .4));
    result.softDark || (result.softDark = (0, color_1.mix)(result.main, -.72));
    result.softDarker || (result.softDarker = (0, color_1.mix)(result.main, -.65));
    result.softDarkest || (result.softDarkest = (0, color_1.mix)(result.main, -.55));
    const waveEffect = (0, color_1.getColor)((_a = result.waveEffect) !== null && _a !== void 0 ? _a : result.main);
    result.waveEffect = `radial-gradient(${waveEffect.alpha(.2).toString()} 0, ${waveEffect.alpha(.3).toString()} 40%, ${waveEffect.alpha(.4).toString()} 50%, ${waveEffect.alpha(.5).toString()} 60%, ${waveEffect.alpha(0).toString()} 70%)`;
    return result;
};
exports.default = createPaletteItem;
